@@ -16,6 +16,7 @@ class Components:
     sort_method_dropdown = html.Div(
         dbc.Select(id='sort_method',
                    placeholder="Select Sorting Method",
+                   # value='Top 20 Net Profit',
                    options=[{'label': 'Top 20 Net Profit', 'value': 'Top 20 Net Profit'},
                             {'label': 'Top 20 Net Profit to MDD', 'value': 'Top 20 Net Profit to MDD'}, ],
                    style={'border-radius': '5px', 'font-size': '12px', }),
@@ -102,12 +103,12 @@ class Components:
                 if _options == [False, True]:
                     _checklist = dcc.Checklist([str(tf) for tf in _options], [str(tf) for tf in _options], inline=True,
                                                id={'type': 'para-checklist', 'index': i},
-                                               labelStyle={'font-size': '11px'},
+                                               labelStyle={},
                                                inputStyle={'margin-left': '10px', 'margin-right': '3px'})
                 else:
                     _checklist = dcc.Checklist(_options, _options, inline=True,
                                                id={'type': 'para-checklist', 'index': i},
-                                               labelStyle={'font-size': '11px'},
+                                               labelStyle={},
                                                inputStyle={'margin-left': '10px', 'margin-right': '3px'})
                 row = html.Div(
                     dbc.Row([
@@ -115,7 +116,7 @@ class Components:
                         html.Div(style={'height': '5px'}),
                         html.Div(_checklist),
                         html.Div(style={'height': '5px'}),
-                    ]), style={'padding': '0px 20px', 'font-size': '11px'})
+                    ]), style={'padding': '0px 20px', 'font-size': '15px'})
 
                 checkbox_div.append(row)
 
@@ -123,7 +124,7 @@ class Components:
 
     def update_stat_div(self, period, pct_mean, rise_mean, fall_mean):
         div = html.Div([
-            html.Div(style={'height': '15px', }),
+            # html.Div(style={'height': '15px', }),
 
              # html.Div('Average', style={'text-align': 'left'}),
              #
@@ -183,14 +184,18 @@ class Components:
         for i, key in enumerate(para_dict):
             options = para_dict[key]
 
-            radioitems_div.append(key)
+            radioitems_div.append(html.Div(key,style={'color': 'Yellow','font-size': '16px'}))
 
             radioitems_div.append(dcc.RadioItems(
                 id={'type': 'para_radioitems', 'index': i},
-                options=[{'label': k, 'value': k} for k in options],
+                options=[{'label': k,
+                          'value': k} for k in options],
+                labelStyle={'font-size': '13px'},
+                inputStyle={'margin-left': '10px', 'margin-right': '5px'}
+
             ), )
 
-            radioitems_div.append(html.Div(html.Img(),style={'height':'5px'}))
+            radioitems_div.append(html.Div(html.Img(),style={'height':'10px'}))
 
         return radioitems_div
 
@@ -219,6 +224,7 @@ class Components:
             df['mdd_pct'] = "{:.0%}".format(df['mdd_pct'] / 100)
             df['return_on_capital'] = "{:.0%}".format(df['return_on_capital'] / 100)
             df['annualized_return'] = "{:.0%}".format(df['annualized_return'] / 100)
+            df['annualized_std'] = "{:.2%}".format(df['annualized_std'] / 100)
 
             df['cov'] = round(df['cov'], 2)
             df['win_rate'] = "{:.0%}".format(df['win_rate'] / 100)
@@ -228,8 +234,9 @@ class Components:
             df['bah_mdd_pct'] = "{:.0%}".format(df['bah_mdd_pct'] / 100)
             df['bah_return'] = "{:.0%}".format(df['bah_return'] / 100)
             df['bah_annualized_return'] = "{:.0%}".format(df['bah_annualized_return'] / 100)
+            df['bah_annualized_std'] = "{:.2%}".format(df['bah_annualized_std'] / 100)
         except Exception as e:
-            # print(e)
+            print(e)
             pass
 
         per_col_1_1.append(html.Div('Number of Trade'))
@@ -313,6 +320,21 @@ class Components:
         return matrix_div
 
 
+    def selection_title(self, para_dict, values):
+        title = [html.Div('Selection',style={'color':'Cyan','font-size': '15px'})]
+        for i, key in enumerate(para_dict):
+            title_div = []
+            title_div.append(html.Div(key, style={'margin-right': '5px', 'display': 'inline'}))
+            title_div.append(html.Div(':', style={'margin-right': '5px', 'display': 'inline'}))
+            title_div.append(html.Div(str(values[i]) + ' ', style={'margin-right': '10px', 'display': 'inline'}))
+            title.append(html.Span(title_div))
+        title.append(html.Div(style={'height': '15px', }),)
+        title.append(html.Div('Performance',style={'color':'Cyan','font-size': '15px'}))
+
+        return title
+
+
+
     filter_options = {
             'num_of_trade':'Trade Count',
             'annualized_sr': 'Sharp Ratio',
@@ -425,14 +447,23 @@ class Components:
 
     def prepare_df_chart(self, df):     # Chart Data for Chart 2
         initial_value = df.iloc[0].equity_value
-        df_chart = pd.DataFrame()
-        df_chart['date'] = pd.to_datetime(df['date'], format='%Y-%m-%d')
-        df_chart['close'] = df['close']
+        # df_chart = pd.DataFrame()
+        # df_chart['date'] = pd.to_datetime(df['date'], format='%Y-%m-%d')
+        # df_chart['close'] = df['close']
+        # df_chart['bah'] = df['close'] * (initial_value / df_chart.iloc[0].close)
+        # df_chart['equity_value'] = df['equity_value']
+        # df_chart['action'] = df['action']
+        # df_chart['volume'] = df['volume']
+        # df_chart['sma'] = df['sma']
+
+        df_chart = df.copy()
+        df_chart['date'] = pd.to_datetime(df_chart['date'], format='%Y-%m-%d')
+        #df_chart['close'] = df['close']
         df_chart['bah'] = df['close'] * (initial_value / df_chart.iloc[0].close)
-        df_chart['equity_value'] = df['equity_value']
-        df_chart['action'] = df['action']
-        df_chart['volume'] = df['volume']
-        df_chart['sma'] = df['sma']
+        # df_chart['equity_value'] = df['equity_value']
+        # df_chart['action'] = df['action']
+        # df_chart['volume'] = df['volume']
+        # df_chart['sma'] = df['sma']
 
         _open = []
         _stop_loss = []
@@ -556,6 +587,8 @@ class Components:
         ])
 
 
+        # fig_line = px.line(df_chart, x='date', y="equity_value",
+        #                    title="Automatic Labels Based on Data Frame Column Names")
         fig_line = px.line(df_chart, x='date', y="equity_value")
         fig_line.update_traces(line_color='rgba(0, 0, 0, 0)')
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
@@ -563,9 +596,12 @@ class Components:
         fig_line.add_trace(go.Scatter(mode='lines', hoverinfo='skip',
                                       x=df_chart['date'], y=df_chart['equity_value'],
                                       line=dict(color=line_colour, width=1), name='Strategy Equity'), )
+        # fig_line.add_trace(go.Scatter(mode='lines', hoverinfo='skip',
+        #                               x=df_chart['date'], y=df_chart['bah'],
+        #                               line=dict(color='#00FFFF', width=1), name='BnH Equity'), )
         fig_line.add_trace(go.Scatter(mode='lines', hoverinfo='skip',
                                       x=df_chart['date'], y=df_chart['bah'],
-                                      line=dict(color='#00FFFF', width=1), name='BnH Equity'), )
+                                      line=dict(color='white', width=1), name='BnH Equity'), )
         fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=height,
                                margin=dict(l=85, r=25, t=25, b=0),
                                font={"color": "white", 'size': 9}, yaxis={'title': 'Equity'},
@@ -601,16 +637,18 @@ class Components:
                     go.Bar(hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
                            marker_color=line_color, marker_line_color=line_color, name=element),
                 ])
-            fig.update_layout(width=683+187)
         else:
             fig = go.Figure(data=[
                 go.Scatter(mode='lines', hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
                            line=dict(color=line_color, width=1.5), name=element), ] )
-            fig.update_layout(width=670+187)
+
+        fig.update_layout(width=823)
         fig.update_layout(plot_bgcolor='#1f2c56', paper_bgcolor='#1f2c56', height=60,
-                          margin=dict(l=85, r=50, t=5, b=20),
+                          margin=dict(l=85, r=50, t=25, b=20),
                           font={"color": "white",'size': 9}, yaxis={'fixedrange': True}, xaxis={'fixedrange': True},
                           bargap=0, )
+        fig.update_layout(legend=dict(orientation="h", bgcolor='rgba(0, 0, 0, 0)',
+                                          yanchor="bottom", y=0.99, xanchor="right", x=0.135))
         fig.update_xaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor='#1f2c56', )
         fig.update_yaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor='#626567', mirror=True)
 
