@@ -65,7 +65,7 @@ class Plot:
                         html.Div(style={'height': '10px', }),
                         html.Div(id='checklist-container',children=checkbox_div),
                         html.Div('-----------------------------------------------',style={'margin-left': '15px'}),
-                        html.Div('Filters:', style={'margin-left': '15px'}),
+                        html.Div('Filters for:', style={'margin-left': '14px'}),
                         html.Div(style={'height': '10px', }),
                         html.Div(id='filter', children=filter_div,style={'padding': '0px 20px',
                                                                          'padding-right': '30px',
@@ -169,6 +169,7 @@ class Plot:
                            sub_chart1_area,sub_chart1,\
                            sub_chart2_area,sub_chart2,hist_area,hist_style, *vals):
 
+
             chart1_button_text = ''
             chart2_button_text = ''
 
@@ -264,7 +265,9 @@ class Plot:
                                 pass
 
                             # Generate Chart 2 after knowing subchart count
-                            fig_line = components.generate_chart_2(df_chart, line_colour, 340 - subchart_count*60 - 20)
+                            # fig_line = components.generate_chart_2(df_chart, line_colour, 340 - subchart_count*60 - 20)
+                            fig_line = components.generate_chart_2(df_chart, line_colour,
+                                                                   440 - subchart_count * 60 - 20)
 
 
 
@@ -334,6 +337,7 @@ class Plot:
                           None, chart1_button_text, chart2_button_text, \
                           sub_chart1_area, sub_chart1, sub_chart2_area, sub_chart2, hist_area, hist_style
 
+
             ## Add Button Pressed
             if add_button_clicks:
                 if add_button_clicks > self.add_button_count: ## Add Button Pressed
